==> git2net-0.9.2.tar.gz: git2net-0.9.2/README.md <==
# git2net

`git2net` is an Open Source Python package that facilitates the extraction of co-editing networks
from git repositories.

## Download and installation

`git2net` is pure `python` code. It has no platform-specific dependencies and thus works on all
platforms. Assuming you are using `pip`, you can install latest version of `git2net` by running:

```
> pip install git2net
```

This also installs the necessary dependencies.

## How to use git2net

We have publised some motivating results as well as details on the mining algorithm in "git2net - Mining Time-Stamped Co-Editing Networks from Large git Repositories. Together with the paper we have released a jupyter notebook reproducing the majority of the results shown in the paper on [zenodo.org](https://zenodo.org/record/2587483#.XK4LPENoSCg). This notebook also serves as tutorial introducing the functionality of `git2net`.

## How to cite git2net

```
@article{DBLP:journals/corr/abs-1903-10180,
  author    = {Christoph Gote and
               Ingo Scholtes and
               Frank Schweitzer},
  title     = {git2net - Mining Time-Stamped Co-Editing Networks from Large git Repositories},
  journal   = {CoRR},
  volume    = {abs/1903.10180},
  year      = {2019},
  url       = {http://arxiv.org/abs/1903.10180},
  archivePrefix = {arXiv},
  eprint    = {1903.10180},
  timestamp = {Mon, 01 Apr 2019 14:07:37 +0200},
  biburl    = {https://dblp.org/rec/bib/journals/corr/abs-1903-10180},
  bibsource = {dblp computer science bibliography, https://dblp.org}
}
```

## License

This software is licensed under the GNU Affero General Public License v3 (AGPL-3.0).

==> git2net-1.0.1.tar.gz: git2net-1.0.1/README.md <==
# git2net

`git2net` is an Open Source Python package that facilitates the extraction of co-editing networks
from git repositories.

## Download and installation

`git2net` is pure `python` code. It has no platform-specific dependencies and thus works on all
platforms. Assuming you are using `pip`, you can install latest version of `git2net` by running:

```
> pip install git2net
```

This also installs the necessary dependencies. `git2net` depends on the `python-Levenshtein` package to compute Levenshtein distances for edited lines of code. On sytems running Windows, automatically compiling this C based module might fail during installation. In this case, unofficial Windows binaries can be found [here](https://www.lfd.uci.edu/~gohlke/pythonlibs/#python-levenshtein), which might help you get started.

## How to use git2net

We have publised some motivating results as well as details on the mining algorithm in "git2net - Mining Time-Stamped Co-Editing Networks from Large git Repositories. Together with the paper we have released a jupyter notebook reproducing the majority of the results shown in the paper on [zenodo.org](https://zenodo.org/record/2587483#.XK4LPENoSCg). This notebook also serves as tutorial introducing the functionality of `git2net`.

## How to cite git2net

```
@article{DBLP:journals/corr/abs-1903-10180,
  author    = {Christoph Gote and
               Ingo Scholtes and
               Frank Schweitzer},
  title     = {git2net - Mining Time-Stamped Co-Editing Networks from Large git Repositories},
  journal   = {CoRR},
  volume    = {abs/1903.10180},
  year      = {2019},
  url       = {http://arxiv.org/abs/1903.10180},
  archivePrefix = {arXiv},
  eprint    = {1903.10180},
  timestamp = {Mon, 01 Apr 2019 14:07:37 +0200},
  biburl    = {https://dblp.org/rec/bib/journals/corr/abs-1903-10180},
  bibsource = {dblp computer science bibliography, https://dblp.org}
}
```

## License

This software is licensed under the GNU Affero General Public License v3 (AGPL-3.0).
